@@ -117,12 +117,12 @@ def diff_constraints(source: obj.Table, target: obj.Table) -> t.List[str]:
 
 
 @register_diff("table")
-def diff_table(source: obj.Table, target: obj.Table) -> t.List[str]:
+def diff_table(ctx: dict, source: obj.Table, target: obj.Table) -> t.List[str]:
     alterations = []
     alterations.extend(diff_columns(source, target))
     alterations.extend(diff_constraints(source, target))
     if alterations:
-        table_id = helpers.get_obj_id(target)
+        table_id = target["identity"]
         statement = "ALTER TABLE {name} {alterations}".format(
             name=table_id,
             alterations=", ".join(alterations),
@@ -132,22 +132,43 @@ def diff_table(source: obj.Table, target: obj.Table) -> t.List[str]:
 
 
 @register_diff("view")
-def diff_view(source: obj.View, target: obj.View) -> t.List[str]:
+def diff_view(
+    ctx: dict,
+    source: obj.View,
+    target: obj.View
+) -> t.List[str]:
+    statements = []
+    descendants = []
+    for obj in ctx["target_inspect"].descendants(target["identity"]):
+        if obj["obj_type"] == "view":
+            descendants.append(obj)
+    for d in reversed(descendants):
+        statements.append(drop_view(ctx, d))
     if source["definition"] != target["definition"]:
         statement = (
-            "CREATE OR REPLACE VIEW %s AS\n" % helpers.get_obj_id(target)
+            "CREATE OR REPLACE VIEW %s AS\n" % target["identity"]
         ) + target["definition"]
-        return [statement]
-    return []
+        statements.append(statement)
+    for d in descendants:
+        statements.append(create_view(ctx, d))
+    return statements
 
 
 @register_diff("index")
-def diff_index(source: obj.Index, target: obj.Index) -> t.List[str]:
+def diff_index(
+    ctx: dict,
+    source: obj.Index,
+    target: obj.Index
+) -> t.List[str]:
     return []
 
 
 @register_diff("function")
-def diff_function(source: obj.Function, target: obj.Function) -> t.List[str]:
+def diff_function(
+    ctx: dict,
+    source: obj.Function,
+    target: obj.Function
+) -> t.List[str]:
     if source["definition"] != target["definition"]:
         # TODO definition needs to be CREATE OR REPLACE
         return [target["definition"]]
@@ -155,28 +176,32 @@ def diff_function(source: obj.Function, target: obj.Function) -> t.List[str]:
 
 
 @register_diff("trigger")
-def diff_trigger(source: obj.Trigger, target: obj.Trigger) -> t.List[str]:
+def diff_trigger(
+    ctx: dict,
+    source: obj.Trigger,
+    target: obj.Trigger
+) -> t.List[str]:
     if source["definition"] != target["definition"]:
-        drop = "DROP TRIGGER %s" % helpers.get_obj_id(source)
+        drop = "DROP TRIGGER %s" % source["identity"]
         create = target["definition"]
         return [drop, create]
     return []
 
 
 @register_diff("enum")
-def diff_enum(source: obj.Enum, target: obj.Enum) -> t.List[str]:
+def diff_enum(ctx: dict, source: obj.Enum, target: obj.Enum) -> t.List[str]:
     rv = []
     common, source_unique, target_unique = diff_identifiers(
         set(source["elements"]), set(target["elements"]))
     if source_unique:
-        enum_id = helpers.get_obj_id(source)
+        enum_id = source["identity"]
         drop = "DROP TYPE %s" % enum_id
         create = helpers.make_enum_create(target)
         rv.extend([drop, create])
         return rv
 
     for el in target_unique:
-        enum_id = helpers.get_obj_id(target)
+        enum_id = target["identity"]
         alter = "ALTER TYPE %s ADD VALUE '%s'" % (enum_id, el)
         rv.append(alter)
 
@@ -184,92 +209,102 @@ def diff_enum(source: obj.Enum, target: obj.Enum) -> t.List[str]:
 
 
 @register_drop("trigger")
-def drop_trigger(trigger: obj.Trigger) -> str:
-    return "DROP TRIGGER %s" % helpers.get_obj_id(trigger)
+def drop_trigger(ctx: dict, trigger: obj.Trigger) -> str:
+    return "DROP TRIGGER %s" % trigger["identity"]
 
 
 @register_create("trigger")
-def create_trigger(trigger: obj.Trigger) -> str:
+def create_trigger(ctx: dict, trigger: obj.Trigger) -> str:
     return trigger["definition"]
 
 
 @register_drop("function")
-def drop_function(function: obj.Function) -> str:
-    return "DROP FUNCTION %s" % helpers.get_obj_id(function)
+def drop_function(ctx: dict, function: obj.Function) -> str:
+    return "DROP FUNCTION %s" % function["identity"]
 
 
 @register_create("function")
-def create_function(function: obj.Trigger) -> str:
+def create_function(ctx: dict, function: obj.Trigger) -> str:
     return function["definition"]
 
 
 @register_drop("enum")
-def drop_enum(enum: obj.Enum) -> str:
-    return "DROP TYPE %s" % helpers.get_obj_id(enum)
+def drop_enum(ctx: dict, enum: obj.Enum) -> str:
+    return "DROP TYPE %s" % enum["identity"]
 
 
 @register_create("enum")
-def create_enum(enum: obj.Enum) -> str:
+def create_enum(ctx: dict, enum: obj.Enum) -> str:
     return helpers.make_enum_create(enum)
 
 
 @register_drop("sequence")
-def drop_sequence(sequence: obj.Sequence) -> str:
-    return "DROP SEQUENCE %s" % helpers.get_obj_id(sequence)
+def drop_sequence(ctx: dict, sequence: obj.Sequence) -> str:
+    return "DROP SEQUENCE %s" % sequence["identity"]
 
 
 @register_create("sequence")
-def create_sequence(sequence: obj.Sequence) -> str:
+def create_sequence(ctx: dict, sequence: obj.Sequence) -> str:
     return helpers.make_sequence_create(sequence)
 
 
 @register_drop("index")
-def drop_index(index: obj.Index) -> str:
-    return "DROP INDEX %s" % helpers.get_obj_id(index)
+def drop_index(ctx: dict, index: obj.Index) -> str:
+    return "DROP INDEX %s" % index["identity"]
 
 
 @register_create("index")
-def create_index(index: obj.Index) -> str:
+def create_index(ctx: dict, index: obj.Index) -> str:
     if not index["is_unique"] and not index["is_pk"]:
         return index["definition"]
     return ""
 
 
 @register_drop("view")
-def drop_view(view: obj.View) -> str:
-    return "DROP VIEW %s" % helpers.get_obj_id(view)
+def drop_view(ctx: dict, view: obj.View) -> str:
+    return "DROP VIEW %s" % view["identity"]
 
 
 @register_create("view")
-def create_view(view: obj.View) -> str:
+def create_view(ctx: dict, view: obj.View) -> str:
     return (
-        "CREATE VIEW %s AS\n" % helpers.get_obj_id(view)
+        "CREATE VIEW %s AS\n" % view["identity"]
     ) + view["definition"]
 
 
 @register_drop("table")
-def drop_table(table: obj.Table) -> str:
-    return "DROP TABLE %s" % helpers.get_obj_id(table)
+def drop_table(ctx: dict, table: obj.Table) -> str:
+    return "DROP TABLE %s" % table["identity"]
 
 
 @register_create("table")
-def create_table(table: obj.Table) -> str:
+def create_table(ctx: dict, table: obj.Table) -> str:
     return helpers.make_table_create(table)
 
 
-def diff(source: obj.DBObject, target: obj.DBObject) -> t.List[str]:
+def diff(
+    ctx: dict,
+    source: obj.DBObject,
+    target: obj.DBObject
+) -> t.List[str]:
     try:
         handler = diff_handlers[source["obj_type"]]
     except KeyError:
         return []
-    return handler(source, target)
+    return handler(ctx, source, target)
 
 
-def create(obj: obj.DBObject) -> str:
+def create(
+    ctx: dict,
+    obj: obj.DBObject
+) -> str:
     handler = create_handlers[obj["obj_type"]]
-    return handler(obj)
+    return handler(ctx, obj)
 
 
-def drop(obj: obj.DBObject) -> str:
+def drop(
+    ctx: dict,
+    obj: obj.DBObject
+) -> str:
     handler = drop_handlers[obj["obj_type"]]
-    return handler(obj)
+    return handler(ctx, obj)
