@@ -8,20 +8,12 @@ if t.TYPE_CHECKING:
 
 Column = t.Tuple[str, str, str, int]
 DatabaseIdDiff = t.Tuple[t.Set[str], t.Set[str], t.Set[str]]
-DBObjectFieldName = t.Union[
-    te.Literal["tables"],
-    te.Literal["views"],
-    te.Literal["indices"],
-    te.Literal["enums"],
-    te.Literal["sequences"],
-    te.Literal["functions"],
-]
-DatabaseDiff = t.Dict[DBObjectFieldName, DatabaseIdDiff]
 Constraint = t.Tuple[str, str]
 
 
 class Table(te.TypedDict):
     obj_type: te.Literal["table"]
+    identity: str
     oid: str
     schema: str
     name: str
@@ -41,6 +33,7 @@ class Table(te.TypedDict):
 
 class View(te.TypedDict):
     obj_type: te.Literal["view"]
+    identity: str
     oid: str
     schema: str
     name: str
@@ -50,6 +43,7 @@ class View(te.TypedDict):
 
 class Index(te.TypedDict):
     obj_type: te.Literal["index"]
+    identity: str
     oid: str
     schema: str
     table_name: str
@@ -69,6 +63,7 @@ class Index(te.TypedDict):
 
 class Sequence(te.TypedDict):
     obj_type: te.Literal["sequence"]
+    identity: str
     schema: str
     name: str
     data_type: str
@@ -84,6 +79,7 @@ class Sequence(te.TypedDict):
 
 class Enum(te.TypedDict):
     obj_type: te.Literal["enum"]
+    identity: str
     oid: str
     schema: str
     name: str
@@ -92,6 +88,7 @@ class Enum(te.TypedDict):
 
 class Function(te.TypedDict):
     obj_type: te.Literal["function"]
+    identity: str
     oid: str
     schema: str
     name: str
@@ -109,6 +106,7 @@ class Function(te.TypedDict):
 
 class Trigger(te.TypedDict):
     obj_type: te.Literal["trigger"]
+    identity: str
     oid: str
     schema: str
     name: str
@@ -127,17 +125,6 @@ class Dependency(te.TypedDict):
     dependency_identity: str
 
 
-class Database(te.TypedDict):
-    tables: t.Dict[str, Table]
-    views: t.Dict[str, View]
-    indices: t.Dict[str, Index]
-    enums: t.Dict[str, Enum]
-    sequences: t.Dict[str, Sequence]
-    functions: t.Dict[str, Function]
-    triggers: t.Dict[str, Trigger]
-    dependencies: "nx.Graph"
-
-
 DBObject = t.Union[
     Table,
     View,
